pub struct Meteora {
pub solana_client: Arc<SolanaClient>,
}Expand description
A client for interacting with the Meteora protocol on Solana Provides methods to fetch account data, program accounts, and SPL token accounts
Fields
solana_client: Arc<SolanaClient>Implementations
Sourceimpl Meteora
impl Meteora
Sourcepub fn new(solana_client: Arc<SolanaClient>) -> Self
pub fn new(solana_client: Arc<SolanaClient>) -> Self
crreate raydium Example
let sol = Solana::new(solana_network_sdk::types::Mode::MAIN);
let raydium = Meteora::new(Arc::new(sol));Sourcepub async fn get_liquidity_pool_dynv2(
&self,
address: &str,
) -> Result<DAMMV2LiquidityPoolData, String>
pub async fn get_liquidity_pool_dynv2( &self, address: &str, ) -> Result<DAMMV2LiquidityPoolData, String>
get dynv2 meteora liquidity pool Example
let sol = Solana::new(solana_network_sdk::types::Mode::MAIN);
let meteora = Meteora::new(Arc::new(sol));
// 5gB4NPgFB3MHFHSeKN4sbaY6t9MB8ikCe9HyiKYid4Td SOL-USDC pool
let pool_data = meteora.get_liquidity_pool_dynv2("5gB4NPgFB3MHFHSeKN4sbaY6t9MB8ikCe9HyiKYid4Td").await;Sourcepub async fn get_liquidity_pool_dyn(
&self,
address: &str,
) -> Result<DAMMLiquidityPoolData, String>
pub async fn get_liquidity_pool_dyn( &self, address: &str, ) -> Result<DAMMLiquidityPoolData, String>
get dynv2 meteora liquidity pool Example
let sol = Solana::new(solana_network_sdk::types::Mode::MAIN);
let meteora = Meteora::new(Arc::new(sol));
// DqAfrGV2GBxpGRsq6Xk1z9ojRncqgLeeVPaKg5bCc24Z SOL-USDC pool
let pool_data = meteora.get_liquidity_pool_dyn("DqAfrGV2GBxpGRsq6Xk1z9ojRncqgLeeVPaKg5bCc24Z").await;Sourcepub async fn get_liquidity_pool_dlmm(
&self,
address: &str,
) -> Result<DLMMLiquidityPoolData, String>
pub async fn get_liquidity_pool_dlmm( &self, address: &str, ) -> Result<DLMMLiquidityPoolData, String>
get dynv2 meteora liquidity pool Example
let sol = Solana::new(solana_network_sdk::types::Mode::MAIN);
let meteora = Meteora::new(Arc::new(sol));
// BjxkogRUDnb72MSBTfsyuq54yntqxyVKozK9WywMszvZ SOL-USDC pool
let pool_data = meteora.get_liquidity_pool_dlmm("BjxkogRUDnb72MSBTfsyuq54yntqxyVKozK9WywMszvZ").await;Sourcepub async fn get_liquidity_pool_dbc(
&self,
address: &str,
) -> Result<DynamicBondingCurvePoolData, String>
pub async fn get_liquidity_pool_dbc( &self, address: &str, ) -> Result<DynamicBondingCurvePoolData, String>
get dynv2 meteora liquidity pool Example
let sol = Solana::new(solana_network_sdk::types::Mode::MAIN);
let meteora = Meteora::new(Arc::new(sol));
// BjxkogRUDnb72MSBTfsyuq54yntqxyVKozK9WywMszvZ SOL-USDC pool
let pool_data = meteora.get_liquidity_pool_dlmm("BjxkogRUDnb72MSBTfsyuq54yntqxyVKozK9WywMszvZ").await;Auto Trait Implementations
impl Freeze for Meteora
impl !RefUnwindSafe for Meteora
impl Send for Meteora
impl Sync for Meteora
impl Unpin for Meteora
impl !UnwindSafe for Meteora